@@ -1,10 +1,11 @@
 import shlex
 import sys
 from subprocess import CalledProcessError
-from typing import Mapping, Pattern, Type, Union
+from typing import Mapping, Pattern, Sequence, Type, Union
 
+import click
 from click import BadParameter, ClickException
-from sentry_sdk import capture_exception
+from sentry_sdk import capture_exception, push_scope
 
 from .helpers.envvar_option import get_used
 
@@ -26,14 +27,20 @@ def get_active_env_vars():
 
 
 def _format_message(self, file=None):
-    return f"{self.message}{get_active_env_vars()}"
+    msg = click.style(self.message, fg="red", bold=True)
+    if hasattr(self, "hint"):
+        styled = click.style(self.hint, fg="cyan", bold=True)
+        hint = f"\n\nHint: {styled}"
+    else:
+        hint = ""
+    return f"{msg}{hint}{get_active_env_vars()}"
 
 
 BadParameter.format_message = _format_message
 
 
 class CliErrorMeta(type):
-    _exit_code_count = 1
+    _exit_code_count = 2
 
     def __new__(cls, name, bases, attrs):
         cls._exit_code_count += 1
@@ -49,7 +56,9 @@ class CliError(ClickException, metaclass=CliErrorMeta):
 
     def show(self):
         if self.report:
-            capture_exception()
+            with push_scope() as scope:
+                scope.level = "info"
+                capture_exception()
         super().show()
 
     def format_message(self):
@@ -58,8 +67,11 @@ class CliError(ClickException, metaclass=CliErrorMeta):
 
 class CliErrorWithHint(CliError):
     def __init__(self, message, hint, **kwargs) -> None:
-        msg = f"{message}\n\nHint: {hint}"
-        super().__init__(msg, **kwargs)
+        self.hint = hint
+        super().__init__(message, **kwargs)
+
+    def __str__(self):
+        return f"{self.message}\n\nHint: {self.hint}"
 
 
 class UnavailableResourceError(CliErrorWithHint):
@@ -122,14 +134,26 @@ class FailedSubprocessError(CliError):
     def __init__(self, wrapped: Union[CalledProcessError, str]):
         if isinstance(wrapped, str):
             super().__init__(wrapped)
+        elif wrapped.stderr:
+            super().__init__(
+                "\n".join(
+                    [
+                        f"Cannot run {shlex.join(wrapped.cmd)}.",
+                        "\nThe original error was:",
+                        wrapped.stderr,
+                    ]
+                )
+            )
         else:
-            super().__init__(f"Cannot run {shlex.join(wrapped.cmd)}")
+            super().__init__(f"Cannot run {shlex.join(wrapped.cmd)}.")
 
 
 class SuppressedError(FailedSubprocessError):
     def __init__(self, wrapped: CalledProcessError, echo=False):
         if echo:
             print(wrapped.stderr, file=sys.stderr)
+        wrapped.stderr = None
+        wrapped.cmd = [wrapped.cmd[0]]
         super().__init__(wrapped)
 
     def show(self):
@@ -161,6 +185,39 @@ class SamlClientNotSetup(CliErrorWithHint):
         )
 
 
-class ExpiredCredentials(CliError):
+class ExpiredCredentials(CliErrorWithHint):
     def __init__(self) -> None:
-        super().__init__("Your AWS credentials have expired.")
+        super().__init__(
+            "Your AWS credentials have expired.",
+            "\n".join(
+                [
+                    "Try running `sym write-creds` again, or run your command with SYM_SESSION_LENGTH=60.",
+                    "For more details, see: https://docs.symops.com/docs/common-issues-sym-cli#error-your-aws-credentials-have-expired",
+                ]
+            ),
+        )
+
+
+class InvalidResource(CliErrorWithHint, BadParameter, KeyError):
+    def __init__(
+        self,
+        resource: str,
+        profiles: Sequence[str],
+        resource_name="resource",
+    ) -> None:
+        super().__init__(
+            f"Invalid {resource_name} name '{resource}'",
+            "\n".join(
+                [
+                    f"Has your Sym Implementer set up {resource} yet?",
+                    f"These are the {resource_name}s available to you:",
+                    *[f"  - {key}" for key in profiles],
+                ]
+            ),
+            report=True,
+        )
+
+
+class UnknownError(CliErrorWithHint):
+    def __init__(self, wrapped: Exception) -> None:
+        super().__init__("An unknown error occurred", str(wrapped), report=True)
