@@ -1,8 +1,8 @@
-from typing import Dict, NamedTuple, Optional, TypedDict
+from typing import Dict, List, NamedTuple, Optional, Tuple, TypedDict
 
 import validators
 
-from ..errors import CliError
+from ..errors import CliError, InvalidResource
 from .config import Config
 
 
@@ -12,6 +12,7 @@ class Profile(NamedTuple):
     arn: str
     aws_saml_url: Optional[str] = None
     ansible_bucket: Optional[str] = None
+    aliases: List[str] = []
 
 
 class OrgParams(TypedDict, total=False):
@@ -46,6 +47,7 @@ LaunchDarklyParams: OrgParams = {
             region="us-east-1",
             arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-production",
             ansible_bucket="launchdarkly-sym-ansible-production",
+            aliases=["prod"],
         ),
         "staging": Profile(
             display_name="Staging",
@@ -53,23 +55,46 @@ LaunchDarklyParams: OrgParams = {
             arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
             ansible_bucket="launchdarkly-sym-ansible-staging",
         ),
+        # "production-dr": Profile(
+        #     display_name="Production DR",
+        #     region="us-east-1",
+        #     arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-dr",
+        #     ansible_bucket="launchdarkly-sym-ansible-dr",
+        #     aliases=["dr", "production_dr"],
+        # ),
         "catamorphic": Profile(
             display_name="Catamorphic",
             region="us-east-1",
             arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic",
             ansible_bucket="launchdarkly-sym-ansible-catamorphic",
         ),
+        # "catamorphic-dr": Profile(
+        #     display_name="Catamorphic DR",
+        #     region="us-east-1",
+        #     arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic",
+        #     ansible_bucket="launchdarkly-sym-ansible-catamorphic-dr",
+        #     aliases=["catamorphic_dr"],
+        # ),
         "prod-intuit": Profile(
             display_name="Prod: Intuit",
             region="us-west-2",
             arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-production",
             ansible_bucket="launchdarkly-sym-ansible-prod-intuit",
+            aliases=["production-intuit", "intuit_production", "intuit_production_use2"],
         ),
+        # "prod-intuit-dr": Profile(
+        #     display_name="Prod: Intuit",
+        #     region="us-west-2",
+        #     arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-production",
+        #     ansible_bucket="launchdarkly-sym-ansible-prod-intuit-dr",
+        #     aliases=["production-intuit-dr", "intuit_production_dr"]
+        # ),
         "staging-intuit": Profile(
             display_name="Staging: Intuit",
             region="us-west-2",
             arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-staging",
             ansible_bucket="launchdarkly-sym-ansible-staging-intuit",
+            aliases=["intuit_staging", "intuit_staging_use2"],
         ),
         "production_apac": Profile(
             display_name="Production: APAC",
@@ -131,6 +156,7 @@ PARAMS: Dict[str, OrgParams] = {
                 region="us-east-1",
                 arn="arn:aws:iam::838419636750:role/SSMTestRoleCustomBucket",
                 ansible_bucket="sym-ansible-dev",
+                aliases=["test_custom", "test_custom2"],
             ),
         },
     },
@@ -200,8 +226,19 @@ def get_resource_env_vars() -> Optional[str]:
         return "SYM_RESOURCE"
 
 
+def get_profile_and_name(resource: str) -> Tuple[str, Profile]:
+    try:
+        return next(
+            (name, profile)
+            for name, profile in get_profiles().items()
+            if resource == name or resource in profile.aliases
+        )
+    except StopIteration:
+        raise InvalidResource(resource, get_profiles().keys())
+
+
 def get_profile(resource: str) -> Profile:
-    return get_profiles()[resource]
+    return get_profile_and_name(resource)[1]
 
 
 def set_login_fields(org: str, email: str):
