@@ -4,6 +4,8 @@ from functools import cached_property
 from pathlib import Path
 from typing import Iterator, Tuple
 
+from sym.cli.errors import InvalidResource
+
 from ..decorators import command_require_bins, intercept_errors, run_subprocess
 from ..helpers.boto import get_identity
 from ..helpers.contexts import push_env
@@ -31,6 +33,15 @@ class AwsProfile(SAMLClient):
         config.read(AwsCredentialsPath)
         return config.has_section(resource)
 
+    @classmethod
+    def check_resource(cls, resource: str):
+        if not cls.validate_resource(resource):
+            config = ConfigParser()
+            config.read(AwsCredentialsPath)
+            raise InvalidResource(
+                resource, config.sections(), resource_name="AWS Profile"
+            )
+
     @cached_property
     def _section(self):
         config = ConfigParser()
@@ -47,7 +58,6 @@ class AwsProfile(SAMLClient):
     @run_subprocess
     @command_require_bins(binary)
     def _exec(self, *args: str, **opts: str) -> Iterator[Tuple[Argument, ...]]:
-        self.log_subprocess_event(args)
         with push_env("AWS_PROFILE", self.resource):
             yield (*args, opts)
 
@@ -69,3 +79,6 @@ class AwsProfile(SAMLClient):
             arn=self._section.get("x_principal_arn"),
             ansible_bucket=self._section.get("x_sym_ansible_bucket"),
         )
+
+    def send_analytics_event(self):
+        pass
