@@ -6,18 +6,23 @@ from configparser import ConfigParser
 from datetime import datetime, timedelta
 from operator import attrgetter
 from pathlib import Path
-from typing import ClassVar, Optional, Sequence, Type
+from typing import ClassVar, Optional, Sequence, Tuple, Type
 from urllib.parse import urlsplit
 
+import click
 import dateutil.parser
 from policyuniverse.arn import ARN
 
-from sym.cli.errors import CliError
 from sym.cli.helpers import segment, validations
 from sym.cli.helpers.config import SymConfigFile
 from sym.cli.helpers.keywords_to_options import keywords_to_options
 from sym.cli.helpers.os import read_write_lock
-from sym.cli.helpers.params import Profile, get_aws_saml_url, get_profile
+from sym.cli.helpers.params import (
+    Profile,
+    get_aws_saml_url,
+    get_profile,
+    get_profile_and_name,
+)
 
 
 class SAMLClient(ABC):
@@ -58,10 +63,19 @@ class SAMLClient(ABC):
     def log_dir(self):
         return self.options.log_dir
 
+    @property
+    def session_length(self):
+        return self.options.session_length
+
     @classmethod
     def validate_resource(cls, resource: str):
         return validations.validate_resource(resource)
 
+    @classmethod
+    def check_resource(cls, resource: str) -> Tuple[str, Profile]:
+        cls.validate_resource(resource)
+        return get_profile_and_name(resource)  # will raise if invalid
+
     def check_is_setup(self):
         if self._checked_setup:
             return
@@ -70,12 +84,14 @@ class SAMLClient(ABC):
         if self.is_setup():
             return
 
-        print(
+        click.secho(
             f"Warning: sym might not function correctly until {self.binary} is setup.",
-            file=sys.stderr,
+            err=True,
+            fg="yellow",
+            bold=True,
         )
         if self.setup_help:
-            print(f"Hint: {self.setup_help}", file=sys.stderr)
+            click.secho(f"Hint: {self.setup_help}\n", err=True, fg="cyan", bold=True)
 
     @classmethod
     def sorted_subclasses(cls):
@@ -153,11 +169,7 @@ class SAMLClient(ABC):
         segment.track("Subprocess Called", global_options=self.options, binary=command[0])
 
     def get_profile(self) -> Profile:
-        try:
-            profile = get_profile(self.resource)
-        except KeyError:
-            raise CliError(f"Invalid resource: {self.resource}")
-
+        profile = get_profile(self.resource)
         self.dprint(f"Using profile {profile}")
         return profile
 
@@ -241,7 +253,8 @@ class SAMLClient(ABC):
         self.dprint(f"writing creds, profile={profile}")
 
         if (
-            self._creds_expiring(buffer=timedelta(minutes=5))
+            self._creds_expiring(buffer=timedelta(minutes=10))
+            or self.session_length
             or not self._profile_matches_caller_identity()
         ):
             self._ensure_session(force=True)
@@ -276,7 +289,7 @@ class SAMLClient(ABC):
 
     def send_analytics_event(self):
         segment.track(
-            "Resource Requested",
+            "Resource Accessed",
             global_options=self.options,
             resource=self.resource,
         )
