@@ -1,3 +1,5 @@
+import functools
+import sys
 from contextlib import contextmanager
 from pathlib import Path
 from typing import Callable, ContextManager, Iterator
@@ -80,10 +82,47 @@ def click_context(sandbox):
 
 
 @pytest.fixture
-def click_setup(sandbox: Sandbox):
+def wrapped_cli_runner():
+    """Yield a click.testing.CliRunner to invoke the CLI."""
+    class_ = CliRunner
+
+    def invoke_wrapper(f):
+        """Augment CliRunner.invoke to emit its output to stdout.
+
+        This enables pytest to show the output in its logs on test
+        failures. Otherwise, the isolated environment swallows everything.
+
+        Seen here: https://github.com/pallets/click/issues/737
+
+        Example:
+            def command_login_tester_with_echo(click_setup):
+                with click_setup() as runner:
+                    result = runner.invoke(click_command, args, echo=True)
+        """
+
+        @functools.wraps(f)
+        def wrapper(*args, **kwargs):
+            echo = kwargs.pop("echo", False)
+            result = f(*args, **kwargs)
+
+            if echo is True:
+                sys.stdout.write(result.output)
+
+            return result
+
+        return wrapper
+
+    class_.invoke = invoke_wrapper(class_.invoke)
+    cli_runner = class_()
+
+    yield cli_runner
+
+
+@pytest.fixture
+def click_setup(sandbox: Sandbox, wrapped_cli_runner):
     @contextmanager
     def context(set_org=True, set_client=True):
-        runner = CliRunner()
+        runner = wrapped_cli_runner
         with runner.isolated_filesystem():
             with sandbox.push_xdg_config_home():
                 if set_client:
@@ -120,6 +159,21 @@ def creds_env_str(creds_env):
 
 @pytest.fixture
 def env_creds(creds_env_str, capture_command: CaptureCommand):
+    """Include this fixture to automatically stub the subprocess
+    that retrieves credentials from the environment.
+
+    Will only work when subprocess is executed with capture_command
+    context. For example:
+
+    def test_with_creds(env_creds, capture_command):
+        with capture_command():
+            execute thing that gets creds
+
+    will successfully use this stub. However this will not:
+
+    def test_with_creds(env_creds):
+        execute thing that gets creds
+    """
     capture_command.register_output(r"env", creds_env_str)
 
 
@@ -144,6 +198,13 @@ def saml_client(sandbox: Sandbox, monkeypatch: MonkeyPatch, creds_env):
 
     monkeypatch.setattr(AwsOkta, "get_creds", get_creds)
 
+    def profile_matches_caller_identity(self):
+        return True
+
+    monkeypatch.setattr(
+        AwsOkta, "_profile_matches_caller_identity", profile_matches_caller_identity
+    )
+
     sandbox.create_binary(f"bin/{AwsOkta.binary}")
     with sandbox.push_exec_path():
         return AwsOkta("test", options=GlobalOptions(debug=False))
